@@ -757,7 +757,7 @@ class ApiModelV4(object):
             
             width = len(line) - len(line.lstrip())
             assert_error(width % TAB_WIDTH == 0, '宽带不是%s的倍数' % TAB_WIDTH, lineno, line)
-            deep = width / TAB_WIDTH
+            deep = int(width / TAB_WIDTH)
             # assert_error(deep <= API_MAX_DEEP_NUM, '深度不能超过%s' % API_MAX_DEEP_NUM, lineno, line)
 
             line = line.strip()
